@@ -12,6 +12,8 @@ distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
+
+This file has been modified by NetworktoCode, LLC.
 """
 from pynautobot.core.response import Record, JsonField
 
@@ -25,3 +27,12 @@ class ObjectChanges(Record):
 
     def __str__(self):
         return self.request_id
+
+
+class CustomFieldChoices(Record):
+    def __str__(self):
+        return self.value
+
+
+class JobResults(Record):
+    data = JsonField
